@@ -130,8 +130,6 @@
 #'  A list with:
 #'   \tabular{ll}{
 #'     \code{call} \tab Matched call. \cr
-#'     \code{formula} \tab formula in the call or \emph{NULL}. \cr
-#'     \code{data} \tab data.frame used as database or \emph{NULL}. \cr
 #'     \code{type} \tab  Type of model specified. \cr
 #'     \code{method} \tab Value of \code{method} argument to compute the 
 #'       Jacobian \cr
@@ -148,10 +146,12 @@
 #'       maximum-likelihood estimates. \cr
 #'     \code{R2} \tab Coefficient of determination for each equation, 
 #'       obtained as the squared of the correlation coefficient between the 
-#'       corresponding explained variable and its estimate. 
-#'       \code{spsurml} also shows a \emph{global} coefficient of
-#'        determination obtained, in the same manner, for the set of 
-#'          the \emph{G} equations. \cr
+#'       corresponding explained variable and fitted values. \cr
+#'     \code{R2 pooled} \tab \emph{Global} coefficient of determination 
+#'       obtained for the set of the \emph{G} equations. 
+#'       It is computed in the same way than uniequational \code{R2} but 
+#'       joining the dependent variable and fitted values in single vectors 
+#'       instead of one vector for each equation. \cr
 #'     \code{Sigma} \tab Estimated covariance matrix for the residuals of 
 #'       the \emph{G} equations. \cr
 #'     \code{fdHess} \tab Logical value of \code{fdHess} argument when 
@@ -229,9 +229,9 @@
 #'
 #' @author
 #'   \tabular{ll}{
-#'   Fernando López  \tab \email{fernando.lopez@@upct.es} \cr
-#'   Román Mínguez  \tab \email{roman.minguez@@uclm.es} \cr
-#'   Jesús Mur  \tab \email{jmur@@unizar.es} \cr
+#'   Fernando Lopez  \tab \email{fernando.lopez@@upct.es} \cr
+#'   Roman Minguez  \tab \email{roman.minguez@@uclm.es} \cr
+#'   Jesus Mur  \tab \email{jmur@@unizar.es} \cr
 #'   }
 #'
 #' @references
@@ -253,11 +253,11 @@
 #'       and applications}, Pion. 
 #'     \item LeSage J and Pace, R.K. (2009). \emph{Introduction to Spatial 
 #'       Econometrics.} CRC Press, Boca Raton.
-#'      \item López, F.A., Mur, J., and Angulo, A. (2014). Spatial model
+#'      \item Lopez, F.A., Mur, J., and Angulo, A. (2014). Spatial model
 #'        selection strategies in a SUR framework. The case of regional
 #'        productivity in EU. \emph{Annals of Regional Science}, 53(1), 197-220.
 #'        <doi:10.1007/s00168-014-0624-2>
-#'     \item Mur, J., López, F., and Herrera, M. (2010). Testing for spatial
+#'     \item Mur, J., Lopez, F., and Herrera, M. (2010). Testing for spatial
 #'       effects in seemingly unrelated regressions.
 #'       \emph{Spatial Economic Analysis}, 5(4), 399-440.
 #'       <doi:10.1080/17421772.2010.516443>
@@ -646,7 +646,7 @@ spsurml <- function(formula = NULL, data = NULL, na.action,
   assign("Tm", Tm, envir = env)
   assign("p", p, envir = env)
   assign("dvars", dvars, envir = env)
-  # CÓDIGO EJEMPLO PARA DETERMINANTE JACOBIANO
+  # CoDIGO EJEMPLO PARA DETERMINANTE JACOBIANO
   if (!(is.null(listw))) {
     assign("listw", listw, envir = env)
     assign("n", length(listw$neighbours), envir = env)
@@ -845,8 +845,7 @@ spsurml <- function(formula = NULL, data = NULL, na.action,
     coefficients <- coefforig
     rest.se <- seorig
   }  
-  ret <- new_spsur(list(call = cl, formula = formula, 
-                        type = type, data = data, W = W,
+  ret <- new_spsur(list(call = cl, type = type, 
                         method = method, Durbin = Durbin, 
                         G = G, N = N, Tm = Tm, 
                         deltas = deltas, deltas.se = deltas.se,  
@@ -859,7 +858,7 @@ spsurml <- function(formula = NULL, data = NULL, na.action,
                         BP = BP, LMM = LMM,
                         residuals = z$residuals, df.residual = df.residual,
                         fitted.values = z$fitted.values, se.fit = NULL,
-                        Y = Y, X = X,  
+                        Y = Y, X = X, W = W,  
                         similar = similar, can.sim = can.sim, 
                         zero.policy = zero.policy, listw_style = listw$style, 
                         interval = interval,  
